@@ -1,9 +1,9 @@
 var indexSectionsWithContent =
 {
-  0: "bcdefghlnoprtv",
+  0: "bcdefglnoprtv",
   1: "c",
   2: "c",
-  3: "ch",
+  3: "c",
   4: "bcdefglnoprtv",
   5: "c",
   6: "c",
